@@ -10,6 +10,10 @@ from medpy.metric.binary import (dc, jc, hd, asd, assd,
                                  positive_predictive_value)
 from sklearn.metrics import (f1_score, precision_score, recall_score)
 
+from .mIoU_and_SeK import mIoU, SeK
+from .multilabel import emr, hamming
+
+
 metrics_map = {
     'dc': dc,
     'jc': jc,
@@ -29,7 +33,10 @@ metrics_map = {
     'mc-f1-score': f1_score,
     'ml-prec': precision_score,
     'ml-recall': recall_score,
-    'ml-f1-score': f1_score
+    'ml-emr': emr,
+    'ml-hamming': hamming,
+    'mIoU': mIoU,
+    'SeK': SeK
 }
 
 
@@ -71,6 +78,7 @@ class Metrics():
                  polyaxon_exp=None,
                  phase='',
                  metrics_strings=['prec'],
+                 num_classes=2,
                  *args, **kwargs):
         super(Metrics, self).__init__(*args, **kwargs)
         self.polyaxon_exp = polyaxon_exp
@@ -79,6 +87,7 @@ class Metrics():
         self.metric_funcs = {}
         self.metrics = {}
         self.multilabel = False
+        self.num_classes = num_classes
         self.initialize_metrics()
 
     def initialize_metrics(self):
@@ -105,7 +114,8 @@ class Metrics():
                                         Sensitivity.
         speci(result, reference)
                                         Specificity.
-        tpr(result, reference)
+        tpr(result, reference)                                           'ml-emr',
+                                           'ml-hamming'
                                         True positive rate.
         tnr(result, reference)
                                         True negative rate.
@@ -207,20 +217,25 @@ class Metrics():
 
         """
         self.metrics['loss'].append(self._transform_tensor(loss))
-        predicted = self._argmax_or_thresholding(predicted)
 
-        for k in self.metric_funcs.keys():
-            predicted = self._transform_tensor(predicted)
-            target = self._transform_tensor(target)
+        if len(self.metric_strings) > 0:
+            predicted = self._argmax_or_thresholding(predicted)
 
-            if 'mc' in k:
-                self.metrics[k].append(self.metric_funcs[k](predicted.flatten(), target.flatten(),
-                                                            average='micro'))
-            elif 'ml' in k:
-                self.metrics[k].append(self.metric_funcs[k](predicted, target,
-                                                            average='samples'))
-            else:
-                self.metrics[k].append(self.metric_funcs[k](predicted, target))
+            for k in self.metric_funcs.keys():
+                predicted = self._transform_tensor(predicted)
+                target = self._transform_tensor(target)
+
+                if 'mc' in k:
+                    self.metrics[k].append(self.metric_funcs[k](predicted.flatten(), target.flatten(),
+                                                                average='micro'))
+                elif 'ml' in k:
+                    self.metrics[k].append(self.metric_funcs[k](predicted, target,
+                                                                average='samples'))
+                elif 'mIoU' in k or 'SeK' in k:
+                    self.metrics[k].append(self.metric_funcs[k](predicted, target,
+                                                                num_classes=self.num_classes))
+                else:
+                    self.metrics[k].append(self.metric_funcs[k](predicted, target))
 
     def crunch_it(self, epoch):
         """Crunch metrics to obtain mean_metrics map.
