@@ -1,6 +1,7 @@
 from .scheduler import get_scheduler
 from .optimizer import get_optimizer
 
+import torch
 from torch.autograd import Variable
 from phobos.metrics.metrics import Metrics
 
@@ -76,10 +77,12 @@ class Runner():
             self.scheduler = None
         self.train_metrics = Metrics(polyaxon_exp=polyaxon_exp,
                                      phase='train',
-                                     metrics_strings=args.metrics)
+                                     metrics_strings=args.metrics,
+                                     num_classes=args.num_classes)
         self.val_metrics = Metrics(polyaxon_exp=polyaxon_exp,
                                    phase='val',
-                                   metrics_strings=args.metrics)
+                                   metrics_strings=args.metrics,
+                                   num_classes=args.num_classes)
         self.epoch = 0
 
     def set_epoch_metrics(self):
@@ -193,8 +196,6 @@ class Runner():
             # clear batch variables from memory
             del input_tensor, label_tensor
 
-        if self.scheduler:
-            self.scheduler.step()
         return self.train_metrics.crunch_it(self.epoch)
 
     def eval_model(self):
@@ -206,17 +207,22 @@ class Runner():
             dictionary of evaluation metrics.
 
         """
-        self.model.eval()
+        # self.model.eval()
+        with torch.no_grad():
+            for input_tensor, label_tensor in self.val_loader:
+                input_tensor, label_tensor = self.tensorize_batch(
+                    input_tensor, label_tensor)
 
-        for input_tensor, label_tensor in self.val_loader:
-            input_tensor, label_tensor = self.tensorize_batch(
-                input_tensor, label_tensor)
+                prediction_tensor, loss = self.eval_forward(
+                    input_tensor, label_tensor)
+                self.val_metrics.compute(prediction_tensor, label_tensor, loss)
 
-            prediction_tensor, loss = self.eval_forward(
-                input_tensor, label_tensor)
-            self.val_metrics.compute(prediction_tensor, label_tensor, loss)
+                # clear batch variables from memory
+                del input_tensor, label_tensor
 
-            # clear batch variables from memory
-            del input_tensor, label_tensor
+        metrics = self.val_metrics.crunch_it(self.epoch)
 
-        return self.val_metrics.crunch_it(self.epoch)
+        if self.scheduler:
+            self.scheduler.step(metrics['val_loss'])
+
+        return metrics
